
    The fact that the conversion operator can be embedded in a normal calculation can be used to
    make your functions *unit*-safe:

    First, let's define a function that computes the kinetic energy of a moving object, given its
    mass and speed:
    ```
    > kineticEnergy(mass, speed) = 0.5 × mass × speed^2 -> J
    ```

    If someone accidentally switches the order of the arguments, he will be presented with a
    confusing error message:

    ```
    > kineticEnergy(40 m/s, 10 kg)

    Conversion error:

      Cannot convert unit kg²·m/s (base units: kg²·m·s⁻¹)
                  to unit J (base units: kg·m²·s⁻²)
    ```

    However, if we define the function with "early conversions":
    ```
    > kineticEnergy(mass, speed) = 0.5 × (mass -> kg) × (speed -> m/s)^2 -> J
    ```

    The error message is much clearer:
    ```
    Conversion error:

      Cannot convert unit m/s (base units: m·s⁻¹)
                  to unit kg
    ```
